@@ -7,3 +7,8 @@
 from kayako.api import KayakoAPI
 from kayako.core.lib import UnsetParameter, FOREVER
 from kayako.objects import *
+
+__NAME__ = 'kayako'
+__VERSION__ = '1.0.03'
+__AUTHOR__ = 'Evan Leis'
+__EMAIL__ = 'engineergod@yahoo.com'
